
package com.werken.forehead;

/*
 $Id: NoSuchEntryMethodException.java,v 1.1.1.1 2002/06/19 13:51:00 werken Exp $

 Copyright 2001 (C) The Werken Company. All Rights Reserved.
 
 Redistribution and use of this software and associated documentation
 ("Software"), with or without modification, are permitted provided
 that the following conditions are met:

 1. Redistributions of source code must retain copyright
    statements and notices.  Redistributions must also contain a
    copy of this document.
 
 2. Redistributions in binary form must reproduce the
    above copyright notice, this list of conditions and the
    following disclaimer in the documentation and/or other
    materials provided with the distribution.
 
 3. The name "Forehead" must not be used to endorse or promote
    products derived from this Software without prior written
    permission of The Werken Company.  For written permission,
    please contact bob@werken.com.
 
 4. Products derived from this Software may not be called "Forehead"
    nor may "Forehead" appear in their names without prior written
    permission of The Werken Company. Forehead is a registered
    trademark of The Werken Company.
 
 5. Due credit should be given to the Forehead Project
    (http://drools.org/).
 
 THIS SOFTWARE IS PROVIDED BY THE WERKEN COMPANY AND CONTRIBUTORS
 ``AS IS'' AND ANY EXPRESSED OR IMPLIED WARRANTIES, INCLUDING, BUT
 NOT LIMITED TO, THE IMPLIED WARRANTIES OF MERCHANTABILITY AND
 FITNESS FOR A PARTICULAR PURPOSE ARE DISCLAIMED.  IN NO EVENT SHALL
 THE WERKEN COMPANY OR ITS CONTRIBUTORS BE LIABLE FOR ANY DIRECT,
 INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES
 (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR
 SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION)
 HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT,
 STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE)
 ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED
 OF THE POSSIBILITY OF SUCH DAMAGE.
 
 */

/** Indicates an error locating the entry-point method.
 *
 *  @author <a href="mailto:bob@eng.werken.com">bob mcwhirter</a>
 */
public class NoSuchEntryMethodException extends ForeheadException
{
    /** The class lacking the entry-point method. */
    private Class entryClass;

    /** A friendly description of the method not found. */
    private String entryMethodDescriptor;

    /** Construct with a class and description of the method
     *  no found.
     *
     *  @param entryClass The entry-point class.
     *  @param entryMethodDescriptor Description of method not found
     *         upon the entry-point class.
     */
    public NoSuchEntryMethodException(Class entryClass,
                                      String entryMethodDescriptor)
    {
        this.entryClass = entryClass;
        this.entryMethodDescriptor = entryMethodDescriptor;
    }

    /** Retrieve the entry-point class.
     *
     *  @return The entry-point class.
     */
    public Class getEntryClass()
    {
        return this.entryClass;
    }

    /** Retrieve the entry-point method description.
     *
     *  @return The entry-point method description.
     */
    public String getEntryMethodDescriptor()
    {
        return this.entryMethodDescriptor;
    }

    /** Retrieve the message.
     *
     *  @return The error message.
     */
    public String getMessage()
    {
        return getEntryClass().getName() + " contains no method matching: " + getEntryMethodDescriptor();
    }
}
